==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-Bq1sRCruTQ18k9MHEFQYZP
key: prettyprinter-convert-ansi-wl-pprint-1.1-Bq1sRCruTQ18k9MHEFQYZP
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: cc5441d8a0fa40f67df8fb13f3fc34e0
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-Bq1sRCruTQ18k9MHEFQYZP
depends:
    base-4.11.1.0 text-1.2.3.0
    prettyprinter-1.2.1-ulgoMvWrcM6vc8QJk50U6
    prettyprinter-ansi-terminal-1.1.1.2-G7azMJzEjlJGspddW7NL7V
    ansi-wl-pprint-0.6.8.2-7B8xc0qlXvTAz6Bn23TdpB
    ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             prettyprinter-1.2.1-ulgoMvWrcM6vc8QJk50U6=ea0daa596e4092633de9dd0538455b6d
             prettyprinter-ansi-terminal-1.1.1.2-G7azMJzEjlJGspddW7NL7V=9c0d8cbf35f805cd6830f2f2cb75384e
             ansi-wl-pprint-0.6.8.2-7B8xc0qlXvTAz6Bn23TdpB=3f10b2698b6bc7ef56b046a5e3421105
             ansi-terminal-0.8.0.4-Ll5nsATqQAoCUSOmfm7Ux8=60434811d26166e1bacacf0138207cc4
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-convert-ansi-wl-pprint-1.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-convert-ansi-wl-pprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-convert-ansi-wl-pprint
version: 1.1
id: prettyprinter-convert-ansi-wl-pprint-1.1-2UbWUb1bOF3GkyR0cnvlIa
key: prettyprinter-convert-ansi-wl-pprint-1.1-2UbWUb1bOF3GkyR0cnvlIa
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: Converter from »ansi-wl-pprint« documents to »prettyprinter«-based ones.
description:
    See README.md
category: User Interfaces, Text
abi: 2520a1a8dfac23fab4608f6360f65534
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Convert.AnsiWlPprint
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-convert-ansi-wl-pprint-1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-convert-ansi-wl-pprint-1.1
hs-libraries: HSprettyprinter-convert-ansi-wl-pprint-1.1-2UbWUb1bOF3GkyR0cnvlIa
depends:
    base-4.11.1.0 text-1.2.3.0
    prettyprinter-1.2.1-FE3jli4KcyKBdF3L8AKAYT
    prettyprinter-ansi-terminal-1.1.1.2-8jROZIpO8frFqua7jdEhIc
    ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END
    ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             prettyprinter-1.2.1-FE3jli4KcyKBdF3L8AKAYT=545299a9e4d7edb60a04381e76f0fada
             prettyprinter-ansi-terminal-1.1.1.2-8jROZIpO8frFqua7jdEhIc=a5f19a5386ff5a3c2707a3769e291f95
             ansi-wl-pprint-0.6.8.2-IrT08V31eRK8A0Je2S5END=f3cad6fdb79194c1feac8d9ccb8ffd58
             ansi-terminal-0.8.1-92I6zmeqYXE2HtFhEfFRK6=892601395148dacdd997061542e42ef5
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html/prettyprinter-convert-ansi-wl-pprint.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-convert-ansi-wl-pprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
